#ifndef CAPTURE_GNSS_FIX_H_
#define CAPTURE_GNSS_FIX_H_

//Wolf includes
#include "gnss/feature/feature_gnss_fix.h"
#include "core/capture/capture_base.h"

//std includes
//

namespace wolf {
    
WOLF_PTR_TYPEDEFS(CaptureGnssFix);

//class CaptureGnssFix
class CaptureGnssFix : public CaptureBase
{
    protected:
        Eigen::VectorXs data_; ///< Raw data.
        Eigen::MatrixXs data_covariance_; ///< Noise of the capture.

    public:
        CaptureGnssFix(const TimeStamp& _ts, SensorBasePtr _sensor_ptr, const Eigen::VectorXs& _data, const Eigen::MatrixXs& _data_covariance);
        virtual ~CaptureGnssFix();
        const Eigen::VectorXs& getData() const;
        const Eigen::MatrixXs& getDataCovariance() const;
        void getDataAndCovariance(Eigen::VectorXs& data, Eigen::MatrixXs& data_cov) const;
};

inline const Eigen::VectorXs& CaptureGnssFix::getData() const
{
    return data_;
}

inline const Eigen::MatrixXs& CaptureGnssFix::getDataCovariance() const
{
    return data_covariance_;
}

inline void CaptureGnssFix::getDataAndCovariance(Eigen::VectorXs& data, Eigen::MatrixXs& data_cov) const
{
    data = data_;
    data_cov = data_covariance_;
}

} //namespace wolf
#endif
